mlstore
=======

![PyPI](https://img.shields.io/pypi/v/mlstore?logo=pypi&color=brightgreen)
![Python Version](https://img.shields.io/pypi/pyversions/mlstore?logo=python)
![Tests](https://img.shields.io/github/actions/workflow/status/Karol-G/mlstore/workflow.yml?branch=main&logo=github)
![Copier Template](https://img.shields.io/badge/copier-template-blue?logo=jinja)
![License](https://img.shields.io/github/license/Karol-G/mlstore)

Dataset format specialied for Machine Learning with blosc2 backend and standardized metadata.

## Installation

You can install mlstore via [pip](https://pypi.org/project/mlstore/):
```bash
pip install mlstore
```

## Usage

```python
from mlstore import __version__

print(__version__)
```

## Contributing

Contributions are welcome! Please open a pull request with clear changes and add tests when appropriate.

## Issues

Found a bug or have a request? Open an issue at https://github.com/Karol-G/mlstore/issues.

## License

Distributed under the MIT license. See `LICENSE` for details.
